docs.rs failed to build rnp-src-0.1.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
rnp-src: compile librnp and all dependencies from source.
This crate is consumed by rnp-rs when the vendored Cargo feature is
enabled. Its build.rs downloads and compiles:
- librnp 0.18.1 (OpenPGP implementation)
- json-c 0.17 (JSON parsing, required by librnp)
- zlib 1.3.1 (compression)
- bzip2 1.0.8 (compression)
Botan is provided by the [botan-src] crate dependency.
After compilation, the install paths are available via [lib_dir] and
[include_dir].